\name{abcnon}
\title{Nonparametric ABC Confidence Limits}
\description{See Efron and Tibshirani (1993) for details on this
  function.}
\keyword{nonparametric}
\keyword{htest}
\alias{abcnon}
\usage{
abcnon(x, tt, epsilon=0.001, 
       alpha=c(0.025, 0.05, 0.1, 0.16, 0.84, 0.9, 0.95, 0.975))
}
\arguments{
\item{x}{the data. Must be either a vector, or a matrix whose rows are
the observations} 
\item{tt}{function defining the parameter in the resampling form
\code{tt(p,x)}, where \code{p} is the vector of proportions and \code{x}
is the data} 
\item{epsilon}{optional argument specifying step size for finite
difference calculations} 
\item{alpha}{optional argument specifying confidence levels desired}
}
\value{
list with following components
\item{limits}{The estimated confidence points, from the ABC and standard normal methods}
\item{stats}{list consisting of \code{t0}=observed value of \code{tt},
  \code{sighat}=infinitesimal jackknife estimate 
 of standard error of \code{tt}, \code{bhat}=estimated bias}
\item{constants}{list consisting of \code{a}=acceleration constant,
  \code{z0}=bias adjustment, \code{cq}=curvature component} 
\item{tt.inf}{approximate influence components of \code{tt}}
\item{pp}{matrix whose rows are the resampling points in the least
  favourable family. The abc confidence points are the function \code{tt}
  evaluated at these points}
}
\references{
Efron, B, and DiCiccio, T. (1992) More accurate confidence intervals 
in exponential families. Biometrika 79, pages 231-245.

Efron, B. and Tibshirani, R. (1993) An Introduction to the Bootstrap.
Chapman and Hall, New York, London.
}
\examples{
# compute abc intervals for the mean
x <- rnorm(10)
theta <- function(p,x) \{sum(p*x)/sum(p)\}
results <- abcnon(x, theta)  
# compute abc intervals for the correlation
x <- matrix(rnorm(20),ncol=2)
theta <- function(p, x)
\{
    x1m <- sum(p * x[, 1])/sum(p)
    x2m <- sum(p * x[, 2])/sum(p)
    num <- sum(p * (x[, 1] - x1m) * (x[, 2] - x2m))
    den <- sqrt(sum(p * (x[, 2] - x1m)^2) *
              sum(p * (x[, 2] - x1m)^2))
    return(num/den)
\}
results <- abcnon(x, theta)   
}
\name{abcpar}
\title{Parametric ABC Confidence Limits}
\description{See Efron and Tibshirani (1993) for details on this
  function.}
\keyword{htest}
\alias{abcpar}
\usage{
abcpar(y, tt, S, etahat, mu, n=rep(1,length(x)),lambda=0.001, 
       alpha=c(0.025, 0.05, 0.1, 0.16))
}
\arguments{
\item{y}{vector of data}
\item{tt}{function of expectation parameter \code{mu} defining the parameter of interest}
\item{S}{maximum likelihood estimate of the covariance matrix of \code{x}}
\item{etahat}{maximum likelihood estimate of the natural parameter eta}
\item{mu}{function giving expectation of \code{x} in terms of eta}
\item{n}{optional argument containing denominators for binomial (vector of
length \code{length(x)})} 
\item{lambda}{optional argument specifying step size for finite difference calculation}
\item{alpha}{optional argument specifying confidence levels desired}
}
\value{
list with the following components
\item{call}{the call to abcpar}
\item{limits}{The nominal confidence level, ABC point, quadratic ABC point, and
standard normal point.} 
\item{stats}{list consisting of  observed value of \code{tt}, estimated standard error and estimated bias}
\item{constants}{list consisting of \code{a}=acceleration constant,
  \code{z0}=bias adjustment, \code{cq}=curvature component}
}
\references{
Efron, B, and DiCiccio, T. (1992) More accurate confidence intervals 
in exponential families. Bimometrika 79, pages 231-245.

Efron, B. and Tibshirani, R. (1993) An Introduction to the Bootstrap.
Chapman and Hall, New York, London.
}
\examples{
# binomial
# x is a p-vector of successes, n is a p-vector of 
#  number of trials
\dontrun{
S <- matrix(0,nrow=p,ncol=p)
S[row(S)==col(S)] <- x*(1-x/n)
mu <- function(eta,n)\{n/(1+exp(eta))\}
etahat <- log(x/(n-x))
#suppose p=2 and we are interested in mu2-mu1
tt <- function(mu)\{mu[2]-mu[1]\}
x <- c(2,4); n <- c(12,12)
a <- abcpar(x, tt, S, etahat,n)
}}

\name{bcanon}
\title{Nonparametric BCa Confidence Limits}
\description{See Efron and Tibshirani (1993) for details on this
  function.}
\keyword{nonparametric}
\alias{bcanon}
\usage{
bcanon(x, nboot, theta, ..., 
       alpha=c(0.025, 0.05, 0.1, 0.16, 0.84, 0.9, 0.95, 0.975))
}
\arguments{
\item{x}{a vector containing the data. To bootstrap  more complex data
  structures (e.g. bivariate data) see the last example below.}
\item{nboot}{number of bootstrap replications}
\item{theta}{function defining the estimator used in constructing the
  confidence points} 
\item{...}{additional arguments for \code{theta}}
\item{alpha}{optional argument specifying confidence levels desired}
}
\value{
  list with the following components
  \item{confpoint}{estimated bca confidence limits}
  \item{z0}{estimated bias correction}
  \item{acc}{estimated acceleration constant}
  \item{u}{jackknife influence values}
}
\references{
Efron, B. and   Tibshirani, R. (1986).  The Bootstrap
Method for standard errors, confidence intervals,
and other measures of   statistical accuracy.
Statistical Science, Vol 1., No. 1, pp 1-35.

Efron, B. (1987). Better bootstrap confidence intervals (with discussion).
J. Amer. Stat. Assoc. vol 82, pg 171

Efron, B. and Tibshirani, R. (1993) An Introduction to the Bootstrap.
Chapman and Hall, New York, London.
}
\examples{
#  bca limits for the  mean 
#  (this is for illustration; 
#   since "mean" is a built in function,
#   bcanon(x,100,mean) would be simpler!)
x <- rnorm(20)                
theta <- function(x)\{mean(x)\}
results <- bcanon(x,100,theta)   
                              
# To obtain bca limits for functions of more 
# complex data structures, write theta
# so that its argument x is the set of observation
# numbers and simply pass as data to bcanon 
# the vector 1,2,..n. 
# For example, find bca limits for
# the correlation coefficient from a set of 15 data pairs:
xdata <- matrix(rnorm(30),ncol=2)
n <- 15
theta <- function(x,xdata)\{ cor(xdata[x,1],xdata[x,2]) \}
results <- bcanon(1:n,100,theta,xdata)
}

\name{bootpred}
\title{Bootstrap Estimates of Prediction Error}
\description{See Efron and Tibshirani (1993) for details on this
  function.}
\keyword{nonparametric}
\alias{bootpred}
\usage{
bootpred(x,y,nboot,theta.fit,theta.predict,err.meas,...)
}
\arguments{
  \item{x}{a matrix containing the predictor (regressor) values. Each row
    corresponds to an observation.}
  \item{y}{a vector containing the response values}
  \item{nboot}{the number of bootstrap replications}
  \item{theta.fit}{function to be cross-validated. Takes \code{x} and
    \code{y} as an argument. See example below.}
  \item{theta.predict}{function producing predicted values for
    \code{theta.fit}. Arguments are a matrix \code{x} of predictors and
    fit object produced by \code{theta.fit}. See example below.}
  \item{err.meas}{function specifying error measure for a single
    response \code{y} and prediction \code{yhat}. See examples below} 
  \item{\dots}{any additional arguments to be passed to
    \code{theta.fit}}
}
\value{
  list with the following components
  \item{app.err}{the apparent error rate - that is, the mean value of
    \code{err.meas} when \code{theta.fit} is applied to \code{x} and
    \code{y}, and then used to predict \code{y}.} 
  \item{optim}{the bootstrap estimate of optimism in \code{app.err}. A useful
    estimate of prediction error is \code{app.err+optim}} 
  \item{err.632}{the ".632" bootstrap estimate of prediction error.}
}
\references{
  Efron, B. (1983). Estimating the error rate of a prediction rule:
  improvements on cross-validation. J. Amer. Stat. Assoc, vol 78. pages
  316-31. 
  
  Efron, B. and Tibshirani, R. (1993) An Introduction to the Bootstrap.
  Chapman and Hall, New York, London.}
}
\examples{
# bootstrap prediction error estimation in least squares
#  regression
x <- rnorm(85)  
y <- 2*x +.5*rnorm(85)                      
theta.fit <- function(x,y)\{lsfit(x,y)\}
theta.predict <- function(fit,x)\{
               cbind(1,x)\%*\%fit$coef         
               \}    
sq.err_function(y,yhat) \{ (y-yhat)^2\}                   
results <- bootpred(x,y,20,theta.fit,theta.predict,
     err.meas=sq.err)  
                                      
# for a classification problem, a standard choice 
# for err.meas would simply count up the
#  classification errors:
miss.clas <- function(y,yhat)\{ 1*(yhat!=y)\}
# with this specification,  bootpred estimates 
#  misclassification rate
}

\name{bootstrap}
\title{Non-Parametric Bootstrapping}
\description{See Efron and Tibshirani (1993) for details on this
  function.}
\keyword{nonparametric}
\alias{bootstrap}
\usage{
bootstrap(x,nboot,theta,..., func=NULL)
}
\arguments{
\item{x}{a vector containing the data. To bootstrap more complex data
  structures (e.g. bivariate data) see the last example below.}
\item{nboot}{The number of bootstrap samples desired.}
\item{theta}{function to be bootstrapped. Takes \code{x} as an argument, and
  may take additional arguments (see below and last example).}
\item{...}{any additional arguments to be passed to \code{theta}}
\item{func}{(optional) argument specifying the functional the
  distribution of thetahat that is desired. 
  If func is specified, the jackknife after-bootstrap estimate of its standard
  error is also returned. See example below.}
}
\value{
  list with the following components:
  \item{thetastar}{the \code{nboot} bootstrap values of \code{theta}}
  \item{func.thetastar}{the functional \code{func} of the bootstrap
    distribution of thetastar, if \code{func} was specified} 
  \item{jack.boot.val}{the jackknife-after-bootstrap values for \code{func}, if \code{func} was specified}
  \item{jack.boot.se}{the jackknife-after-bootstrap standard error
    estimate of \code{func}, if \code{func} was specified} 
}
\references{
  Efron, B. and   Tibshirani, R. (1986).  The bootstrap
  method for standard errors, confidence intervals,
  and other measures of   statistical accuracy.
  Statistical Science, Vol 1., No. 1, pp 1-35.

  Efron, B. (1992) Jackknife-after-bootstrap standard errors and
  influence functions. J. Roy. Stat. Soc. B, vol 54, pages 83-127
  
  Efron, B. and Tibshirani, R. (1993) An Introduction to the Bootstrap.
  Chapman and Hall, New York, London.
}
\examples{
# 100 bootstraps of the sample mean 
# (this is for illustration;  since "mean" is  a 
# built in function, bootstrap(x,100,mean) would be simpler!)
x <- rnorm(20)                
theta <- function(x)\{mean(x)\} 
                              
results <- bootstrap(x,100,theta)     
                             
# as above, but also estimate the 95th percentile   
# of the bootstrap dist'n of the mean, and         
# its jackknife-after-bootstrap  standard error    
                              
perc95 <- function(x)\{quantile(x, .95)\}
                             
                             
results <-  bootstrap(x,100,theta, func=perc95)                                   
                                   
# To bootstrap functions of more complex data structures, 
# write theta so that its argument x
#  is the set of observation numbers  
#  and simply  pass as data to bootstrap the vector 1,2,..n. 
# For example, to bootstrap
# the correlation coefficient from a set of 15 data pairs:
xdata <- matrix(rnorm(30),ncol=2)
n <- 15
theta <- function(x,xdata)\{ cor(xdata[x,1],xdata[x,2]) \}
results <- bootstrap(1:n,20,theta,xdata)
}

\name{boott}
\title{Bootstrap-t Confidence Limits}
\description{See Efron and Tibshirani (1993) for details on this
  function.}
\keyword{nonparametric}
\alias{boott}
\usage{
boott(x,theta, ..., sdfun=MISSING, nbootsd=25, nboott=200,
      VS=FALSE, v.nbootg=100, v.nbootsd=25, v.nboott=200,
      perc=c(.001,.01,.025,.05,.10,.50,.90,.95,.975,.99,.999))
}
\arguments{
  \item{x}{a vector containing the data. Nonparametric bootstrap sampling is
    used. To bootstrap from more complex data structures (e.g.
    bivariate data) see the last example below.}
  \item{theta}{function to be bootstrapped. Takes \code{x} as an argument, and
    may take additional arguments (see below and last example).}
  \item{...}{any additional arguments to be passed to \code{theta}}
  \item{sdfun}{optional name of function for computing standard
    deviation of \code{theta} based on data \code{x}. Should be
    of the form: \code{sdmean <- function(x,nbootsd,theta,...)} where
    \code{nbootsd} 
    is a dummy argument that is not used. If \code{theta} is the mean,
    for example, 
    \code{sdmean <- function(x,nbootsd,theta,...) \{sqrt(var(x)/length(x))\}} .
    If \code{sdfun} is missing, then \code{boott} uses an inner
    bootstrap loop to estimate the 
    standard deviation of \code{theta(x)}}
  \item{nbootsd}{The number of bootstrap samples used to estimate the
    standard deviation of \code{theta(x)}} 
  \item{nboott}{The number of bootstrap samples used to estimate the
    distribution of the bootstrap T statistic. 
    200 is a bare minimum and 1000 or more is needed for 
    reliable  \eqn{\alpha \%} confidence points, \eqn{\alpha > .95} say. 
    Total number of bootstrap samples is 
    \code{nboott*nbootsd}.}
  \item{VS}{If \code{TRUE}, a variance stabilizing transformation is
    estimated, 
    and the interval is constructed on the transformed scale, and then
    is mapped back to the original theta scale. 
    This can improve both the statistical properties of the intervals and
    speed up the computation. See the reference Tibshirani (1988) given below.
    If \code{FALSE}, variance stabilization is not performed.}
  \item{v.nbootg}{The number of bootstrap samples used to estimate the
    variance stabilizing transformation g. 
    Only used if \code{VS=TRUE}.}
  \item{v.nbootsd}{The number of bootstrap samples used to estimate the
    standard deviation of \code{theta(x)}. 
    Only used if \code{VS=TRUE}.}
  \item{v.nboott}{The number of bootstrap samples used to estimate the
    distribution of 
    the bootstrap T statistic. Only used if \code{VS=TRUE}. Total number of
    bootstrap samples is \code{v.nbootg*v.nbootsd + v.nboott}.} 
  \item{perc}{Confidence points desired.}
}
\value{
  list with the following components:
  \item{confpoints}{Estimated confidence points}
  \item{theta, g}{\code{theta}
    and \code{g} are only returned if \code{VS=TRUE} was
    specified. \code{(theta[i],g[i]),  i=1,length(theta)} 
    represents the estimate of the variance stabilizing transformation
    \code{g} at the points
    \code{theta[i]}.}
}
\references{
  Tibshirani, R. (1988) "Variance stabilization and the bootstrap". Biometrika (1988) vol 75
  no 3 pages 433-44.
  
  Hall, P. (1988) Theoretical comparison of bootstrap confidence
  intervals. Ann. Statisi. 16, 1-50.
  
  Efron, B. and Tibshirani, R. (1993) An Introduction to the Bootstrap.
  Chapman and Hall, New York, London.
}
\examples{
#  estimated confidence points for the mean
x <- rchisq(20,1)
theta <- function(x)\{mean(x)\}
results <- boott(x,theta)
# estimated confidence points for the mean, 
#  using variance-stabilization bootstrap-T method
results <-  boott(x,theta,VS=TRUE)
results$confpoints          # gives confidence points
# plot the estimated var stabilizing transformation
plot(results$theta,results$g) 
# use standard formula for stand dev of mean
# rather than an inner bootstrap loop
sdmean <- function(x, ...) 
    \{sqrt(var(x)/length(x))\}
results <-  boott(x,theta,sdfun=sdmean) 
                                     
# To bootstrap functions of more  complex data structures, 
# write theta so that its argument x
#  is the set of observation numbers  
#  and simply  pass as data to boot the vector 1,2,..n. 
# For example, to bootstrap
# the correlation coefficient from a set of 15 data pairs:                              
xdata <- matrix(rnorm(30),ncol=2)
n <- 15
theta <- function(x, xdata)\{ cor(xdata[x,1],xdata[x,2]) \}
results <- boott(1:n,theta, xdata)
}

\name{crossval}
\title{K-fold Cross-Validation}
\description{See Efron and Tibshirani (1993) for details on this
  function.}
\keyword{nonparametric}
\alias{crossval}
\usage{
crossval(x, y, theta.fit, theta.predict, ..., ngroup=n)
}
\arguments{
\item{x}{a matrix containing the predictor (regressor) values. Each row
corresponds to an observation.}
\item{y}{a vector containing the response values}
\item{theta.fit}{function to be cross-validated. Takes \code{x} and
  \code{y} as an argument. See example below.}
\item{theta.predict}{function producing predicted values for
  \code{theta.fit}.
  Arguments are a matrix x of predictors and fit object produced by theta.fit.
  See example below.}
\item{...}{any additional arguments to be passed to theta.fit}
\item{ngroup}{optional argument specifying the number of  groups formed .
  Default is \code{ngroup}=sample size, corresponding to leave-one out
  cross-validation.} 
}
\value{
  list with the following components
  \item{cv.fit}{The  cross-validated fit for each observation.  The
    numbers 1 to n (the sample size) are  partitioned into \code{ngroup}
    mutually disjoint 
    groups  of size "leave.out".  leave.out, the number of observations in
    each group, is the integer part of n/ngroup.  The groups are chosen
    at random if ngroup < n.  (If n/leave.out is not an integer, the last
    group will contain > leave.out observations).  Then theta.fit is applied
    with the kth group of observations deleted, for k=1, 2, ngroup.
    Finally, the fitted value is computed for the kth group using
    \code{theta.predict}.} 
  \item{ngroup}{The number of groups}
  \item{leave.out}{The number of observations in each group}
  \item{groups}{A list of length ngroup containing the indices of the
    observations 
    in each group. Only returned if \code{leave.out > 1}.}
}
\references{
  Stone, M. (1974).  Cross-validation choice and assessment of
  statistical predictions. Journal of the Royal Statistical Society,
  B-36, 111--147.
  
  Efron, B. and Tibshirani, R. (1993) An Introduction to the Bootstrap.
  Chapman and Hall, New York, London.
}
\examples{
# cross-validation of least squares regression
# note that crossval is not very efficient, and being a
#  general purpose function, it does not use the
# Sherman-Morrison identity for this special case
x <- rnorm(85)  
y <- 2*x +.5*rnorm(85)                      
theta.fit <- function(x,y)\{lsfit(x,y)\}
theta.predict <- function(fit,x)\{
               cbind(1,x)\%*\%fit$coef         
               \}                       
results <- crossval(x,y,theta.fit,theta.predict,ngroup=6)  
                                      
}

\name{bootstrap.data}
\title{Data sets of package bootstrap}
\alias{cell}
\alias{cholost}
\alias{hormone}
\alias{law}
\alias{law82}
\alias{lutenhorm}
\alias{mouse.c}
\alias{mouse.t}
\alias{scor}
\alias{spatial}
\alias{stamp}
\description{
  See Efron and Tibshirani (1993) for details on these
  datasets.
}
\keyword{datasets}
\name{bootstrap-internal}
\alias{ctsub}
\alias{xinter}
\alias{yinter}
\title{Internal functions of package bootstrap}
\description{
  Internal functions of package bootstrap.
}
\usage{
ctsub(x, y, z)
xinter(x, y, z, increasing = TRUE)
yinter(x, y, z, increasing = TRUE)
}
\details{
  These are not to be called by the user.
}
\keyword{internal}
\name{jackknife}
\title{Jackknife Estimation}
\description{See Efron and Tibshirani (1993) for details on this
  function.}
\keyword{nonparametric}
\alias{jackknife}
\usage{
jackknife(x, theta, ...)
}
\arguments{
  \item{x}{a vector containing the data. To jackknife  more complex data
    structures (e.g. bivariate data) see the last example below.}
  \item{theta}{function to be jackknifed. Takes \code{x} as an argument, and
    may take additional arguments (see below and last example).}
  \item{...}{any additional arguments to be passed to \code{theta}}
}
\value{
  list with the following components
  \item{jack.se}{The jackknife estimate of standard error of \code{theta}.
    The leave-one out jackknife is used.}
  \item{jack.bias}{The jackknife estimate of bias of \code{theta}.
    The leave-one out jackknife is used.}
  \item{jack.values}{The n leave-one-out values of \code{theta}, 
    where n is the number of observations.
    That is, \code{theta} applied to \code{x} with
    the 1st observation deleted, \code{theta} applied to \code{x} with
    the 2nd observation deleted, etc.}
}
\references{
  Efron, B. and   Tibshirani, R. (1986).  The Bootstrap
  Method for standard errors, confidence intervals,
  and other measures of   statistical accuracy.
  Statistical Science, Vol 1., No. 1, pp 1-35.

  Efron, B. and Tibshirani, R. (1993) An Introduction to the Bootstrap.
  Chapman and Hall, New York, London.
}
\examples{
# jackknife values for the sample mean 
# (this is for illustration;  # since "mean" is  a 
#  built in function,  jackknife(x,mean) would be simpler!)
x <- rnorm(20)               
theta <- function(x)\{mean(x)\}
                             
results <- jackknife(x,theta)        
                              
# To jackknife functions of more  complex data structures, 
# write theta so that its argument x
#  is the set of observation numbers  
#  and simply  pass as data to jackknife the vector 1,2,..n. 
# For example, to jackknife
# the correlation coefficient from a set of 15 data pairs:      
                        
xdata <- matrix(rnorm(30),ncol=2)
n <- 15
theta <- function(x,xdata)\{ cor(xdata[x,1],xdata[x,2]) \}
results <- jackknife(1:n,theta,xdata)
}

